@@ -201,10 +201,22 @@ def create_table_from_data_util(create_table_request: CreateTableRequest, connec
                         if any(pattern in col_lower for pattern in common_boolean_patterns):
                             logger.info(f"Found potential boolean column by name pattern: {col}")
                             boolean_columns.add(col)
+                
+                logger.info(f"Final boolean columns after fallback: {boolean_columns}")
             
             # Use cleaned column names for INSERT
             original_cols = list(data_list[0].keys())
             cleaned_cols = [col_name_map[col] for col in original_cols]
+            
+            # Map boolean columns to their cleaned names
+            cleaned_boolean_columns = set()
+            for col in boolean_columns:
+                if col in col_name_map:
+                    cleaned_boolean_columns.add(col_name_map[col])
+                    logger.info(f"Boolean column '{col}' mapped to cleaned name '{col_name_map[col]}'")
+                else:
+                    logger.warning(f"Boolean column '{col}' not found in column name mapping")
+            
             cols_sql = ", ".join(f"`{c}`" for c in cleaned_cols)
             ph = ", ".join(["%s"] * len(cleaned_cols))
             total = 0
@@ -217,15 +229,17 @@ def create_table_from_data_util(create_table_request: CreateTableRequest, connec
                 
                 # Convert boolean values before insertion
                 vals = []
-                for row in data_list:
+                for i, row in enumerate(data_list):
                     row_vals = []
-                    for col in original_cols:
+                    for j, col in enumerate(original_cols):
                         val = row[col]
+                        cleaned_col = cleaned_cols[j]
                         if pd.isna(val):
                             row_vals.append(None)
-                        elif col in boolean_columns:
+                        elif cleaned_col in cleaned_boolean_columns:
                             # Convert boolean values to 1/0
-                            row_vals.append(_convert_boolean_values(val))
+                            converted_val = _convert_boolean_values(val)
+                            row_vals.append(converted_val)
                         else:
                             row_vals.append(val)
                     vals.append(tuple(row_vals))
